@@ -37,9 +37,7 @@ def mpr():
     rester.session.close()
 
 
-@pytest.mark.skipif(
-    os.environ.get("MP_API_KEY", None) is None, reason="No API key found."
-)
+@pytest.mark.skipif(os.environ.get("MP_API_KEY", None) is None, reason="No API key found.")
 class TestMPRester:
     def test_get_structure_by_material_id(self, mpr):
         s1 = mpr.get_structure_by_material_id("mp-149")
@@ -68,7 +66,7 @@ class TestMPRester:
         )
         assert len(results) > 0
 
-    def test_get_materials_id_references(self, mpr):
+    def test_get_materials_ids_references(self, mpr):
         data = mpr.get_materials_id_references("mp-123")
         assert len(data) > 5
 
@@ -251,111 +249,10 @@ class TestMPRester:
         chgcar = mpr.get_charge_density_from_material_id("mp-149")
         assert isinstance(chgcar, Chgcar)
 
-        chgcar, task_doc = mpr.get_charge_density_from_material_id(
-            "mp-149", inc_task_doc=True
-        )
+        chgcar, task_doc = mpr.get_charge_density_from_material_id("mp-149", inc_task_doc=True)
         assert isinstance(chgcar, Chgcar)
         assert isinstance(task_doc, TaskDoc)
 
     def test_get_wulff_shape(self, mpr):
         ws = mpr.get_wulff_shape("mp-126")
         assert isinstance(ws, WulffShape)
-
-    def test_query(self, mpr):
-
-        excluded_params = [
-            "sort_fields",
-            "chunk_size",
-            "num_chunks",
-            "all_fields",
-            "fields",
-            "equilibrium_reaction_energy",  # temp until data update
-        ]
-
-        alt_name_dict = {
-            "material_ids": "material_id",
-            "formula": "formula_pretty",
-            "exclude_elements": "formula_pretty",
-            "piezoelectric_modulus": "e_ij_max",
-            "crystal_system": "symmetry",
-            "spacegroup_symbol": "symmetry",
-            "spacegroup_number": "symmetry",
-            "total_energy": "energy_per_atom",
-            "formation_energy": "formation_energy_per_atom",
-            "uncorrected_energy": "uncorrected_energy_per_atom",
-            "equilibrium_reaction_energy": "equilibrium_reaction_energy_per_atom",
-            "magnetic_ordering": "ordering",
-            "elastic_anisotropy": "universal_anisotropy",
-            "poisson_ratio": "homogeneous_poisson",
-            "piezoelectric_modulus": "e_ij_max",
-            "surface_energy_anisotropy": "surface_anisotropy",
-        }  # type: dict
-
-        custom_field_tests = {
-            "material_ids": ["mp-149"],
-            "formula": "SiO2",
-            "chemsys": "Si-O",
-            "elements": ["Si", "O"],
-            "exclude_elements": ["Si"],
-            "possible_species": ["O2-"],
-            "crystal_system": CrystalSystem.cubic,
-            "spacegroup_number": 38,
-            "spacegroup_symbol": "Amm2",
-            "has_props": [HasProps.dielectric],
-            "theoretical": True,
-            "has_reconstructed": False,
-            "magnetic_ordering": Ordering.FM,
-        }  # type: dict
-
-        search_method = mpr.query
-
-        # Get list of parameters
-        param_tuples = list(typing.get_type_hints(search_method).items())
-
-        # Query API for each numeric and boolean parameter and check if returned
-        for entry in param_tuples:
-            param = entry[0]
-            if param not in excluded_params:
-                param_type = entry[1].__args__[0]
-                q = None
-
-                if param in custom_field_tests:
-                    project_field = alt_name_dict.get(param, None)
-                    q = {
-                        param: custom_field_tests[param],
-                        "chunk_size": 1,
-                        "num_chunks": 1,
-                    }
-                elif param_type == typing.Tuple[int, int]:
-                    project_field = alt_name_dict.get(param, None)
-                    q = {
-                        param: (-100, 100),
-                        "chunk_size": 1,
-                        "num_chunks": 1,
-                    }
-                elif param_type == typing.Tuple[float, float]:
-                    project_field = alt_name_dict.get(param, None)
-                    q = {
-                        param: (-100.12, 100.12),
-                        "chunk_size": 1,
-                        "num_chunks": 1,
-                    }
-                elif param_type is bool:
-                    project_field = alt_name_dict.get(param, None)
-                    q = {
-                        param: False,
-                        "chunk_size": 1,
-                        "num_chunks": 1,
-                    }
-
-                docs = search_method(**q)
-
-                if len(docs) > 0:
-                    doc = docs[0].dict()
-                else:
-                    raise ValueError("No documents returned")
-
-                assert (
-                    doc[project_field if project_field is not None else param]
-                    is not None
-                )
