@@ -4,10 +4,15 @@ from mp_api.routes.xas import XASRester
 from emmet.core.xas import Edge
 from pymatgen.core.periodic_table import Element
 
-import inspect
 import typing
 
-resters = [XASRester()]
+
+@pytest.fixture
+def rester():
+    rester = XASRester()
+    yield rester
+    rester.session.close()
+
 
 excluded_params = [
     "sort_fields",
@@ -39,13 +44,8 @@ custom_field_tests = {
 @pytest.mark.skipif(
     os.environ.get("MP_API_KEY", None) is None, reason="No API key found."
 )
-@pytest.mark.parametrize("rester", resters)
 def test_client(rester):
-    # Get specific search method
-    search_method = None
-    for entry in inspect.getmembers(rester, predicate=inspect.ismethod):
-        if "search" in entry[0] and entry[0] != "search":
-            search_method = entry[1]
+    search_method = rester.search
 
     if search_method is not None:
         # Get list of parameters
